synphot
=======

.. image:: https://img.shields.io/badge/ascl-1811.001-blue.svg?colorB=262255
    :target: http://ascl.net/1811.001
    :alt: ascl:1811.001

.. image:: https://readthedocs.org/projects/synphot/badge/?version=latest
    :target: http://synphot.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. image:: https://dev.azure.com/spacetelescope/synphot_refactor/_apis/build/status/spacetelescope.synphot_refactor?branchName=master
    :target: https://dev.azure.com/spacetelescope/synphot_refactor/_build/latest?definitionId=2&branchName=master
    :alt: Azure CI Status

.. image:: https://codecov.io/gh/spacetelescope/synphot_refactor/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/spacetelescope/synphot_refactor
    :alt: Coverage results

This is a replacement for IRAF STSDAS SYNPHOT and ASTROLIB PYSYNPHOT,
utilizing Astropy and covering the non-instrument specific portions
of the old packages.
